%Parameter initialization for planar robot simulator
clear all
clc

addpath('rvctools')

startup_rvc;


%Parameters for the reference generator
omega = 1;
ksi = 1;
param1=(2*ksi+1)*omega;
param2 = (2*ksi+1)*omega^2;



g=9.81;
m1=7.3; %Mass body 1
m2=31.9; %Mass body 2
m3=19.3; %Mass body 3
m4=13.3; %Mass body 4
m5= 1.2; %Mass body 5
m6=2; %Mass body 6
M=[m1;m2;m3;m4;m5;m6]; %Simple mass matrix


%System parameters
d6 = 0.359; %[m]
a1=0.153;%[m]
a2=0.663;%[m]
a3=0.401;%[m]
a4=0.121;%[m]
a5 = 0.1796;%[m]
a6 = 0.1796;%[m]

LEN = [d6;a1;a2;a3;a4];

PSI = [0.1;0.1;0.1;0.1;0.1;0.1];

LENGTH=[a1;a2;a3;a4;a5;a6];     

%Setting up width and height of all cross-sections: 

w = 0.127;
he = 0.127;

%Link1
w1 = w;
he1 = he;

%Link2
w2 = w;
he2 = he;

%Link3
w3 = w;
he3 = he;

%Link4
w4 = w;
he4 = he;

%Link5
w5 = w;
he5 = he;

%Link6
w6 = w;
he6 = he;


%Setting up the moment of inertias (Assuming that all cross-sections are
%quadratic)

I1x = (1/12)*m1*(w1^2 + he1^2);
I1y = (1/12)*m1*(a1^2 + w1^2);
I1z = (1/12)*m1*(a1^2 + he1^2);


I2x = (1/12)*m2*(w2^2 + he2^2);
I2y = (1/12)*m2*(a2^2 + w2^2);
I2z = (1/12)*m2*(a2^2 + he2^2);



I3x = (1/12)*m3*(w3^2 + he3^2);
I3y = (1/12)*m3*(a3^2 + w3^2);
I3z = (1/12)*m3*(a3^2 + he3^2);


I4x = (1/12)*m4*(w4^2 + he4^2);
I4y = (1/12)*m4*(a4^2 + he4^2);
I4z = (1/12)*m4*(a4^2 + w4^2);


I5x = (1/12)*m5*(a5^2 + he5^2);
I5y = (1/12)*m5*(a5^2 + w5^2);
I5z = (1/12)*m5*(w5^2 + he5^2);


I6x = (1/12)*m6*(a6^2 + he6^2);
I6y = (1/12)*m6*(a6^2 + w6^2);
I6z = (1/12)*m6*(w6^2 + he6^2);

Inert = [I1x,I1y,I1z;I2x,I2y,I2z;I3x,I3y,I3z;I4x,I4y,I4z;I5x,I5y,I5z;I6x,I6y,I6z];

%Friction constant
f=[50;50;50;50;50;50]; 

%Setting up the L-matrix
l=[2,2,2,2,2,2];

gainL=diag(l);

%Setting up the H-matrix
h=[2,2,2,2,2,2];

H=diag(h);

%Setting up the epsilon vectors:

eps1 = [0.1;0.1;0.1;0.1;0.1;0.1];

eps2 = [0.1;0.1;0.1;0.1;0.1;0.1];


%Choosing gain parameters:

h0=1.5;
l0=1.5;
k0=0.5;

T=sqrt(6)/(k0*h0);

rho=1;

K=diag([0.8,0.8,0.8,0.8,0.8,0.8]);

P = 10;

A = diag([10,10,10,10,10,10]);

%Setting up the six_link object
Lp(1) = Link([0, 0, 0.153, pi/2, 0]);
Lp(2) = Link([0, 0, 0.663, 0, 0]);
Lp(3) = Link([0, 0, 0.401, 0, 0]);
Lp(4) = Link([0, 0, 0.121, pi/2, 0]);
Lp(5) = Link([0, 0, 0, -pi/2, 0]);
Lp(6) = Link([0, 0.480, 0, 0, 0]);

six_link = SerialLink(Lp,'name', 'six link');


